@@ -30,8 +30,16 @@ class Component(Enum):
     Django = 7004
     Tornado = 7005
     Redis = 7
+    MongoDB = 9
     KafkaProducer = 40
     KafkaConsumer = 41
+    RabbitmqProducer = 52
+    RabbitmqConsumer = 53
+    Elasticsearch = 47
+    Urllib3 = 7006
+    Sanic = 7007
+    AioHttp = 7008
+    Pyramid = 7009
 
 
 class Layer(Enum):
