@@ -16,7 +16,7 @@
 #
 
 import atexit
-from queue import Queue
+from queue import Queue, Full
 from threading import Thread, Event
 from typing import TYPE_CHECKING
 
@@ -73,6 +73,15 @@ def __fini():
 
 
 def start():
+    flag = False
+    try:
+        from gevent import monkey
+        flag = monkey.is_module_patched("socket")
+    except ModuleNotFoundError:
+        logger.debug("it was found that no gevent was used, if you don't use, please ignore.")
+    if flag:
+        import grpc.experimental.gevent as grpc_gevent
+        grpc_gevent.init_gevent()
     global __started
     if __started:
         raise RuntimeError('the agent can only be started once')
@@ -100,8 +109,7 @@ def connected():
 
 
 def archive(segment: 'Segment'):
-    if __queue.full():
+    try:  # unlike checking __queue.full() then inserting, this is atomic
+        __queue.put(segment, block=False)
+    except Full:
         logger.warning('the queue is full, the segment will be abandoned')
-        return
-
-    __queue.put(segment)
